@@ -1,8 +1,8 @@
+#
+# $Id: DescL2.pm,v 1.2.2.14 2005/05/22 19:47:48 gomor Exp $
+#
 package Net::Packet::DescL2;
 
-# $Date: 2005/02/01 16:29:16 $
-# $Revision: 1.2.2.12 $
-
 use strict;
 use warnings;
 use Carp;
@@ -10,9 +10,6 @@ use Carp;
 require Net::Packet::Desc;
 our @ISA = qw(Net::Packet::Desc);
 
-require Net::Packet;
-our $VERSION = $Net::Packet::VERSION;
-
 use IO::Socket;
 
 BEGIN {
