@@ -1,8 +1,8 @@
+#
+# $Id: DescL3.pm,v 1.2.2.19 2005/05/22 19:47:48 gomor Exp $
+#
 package Net::Packet::DescL3;
 
-# $Date: 2005/02/01 16:29:16 $
-# $Revision: 1.2.2.17 $
-
 use strict;
 use warnings;
 
@@ -10,9 +10,6 @@ require Net::Packet::Desc;
 require Class::Gomor::Hash;
 our @ISA = qw(Net::Packet::Desc Class::Gomor::Hash);
 
-require Net::Packet;
-our $VERSION = $Net::Packet::VERSION;
-
 use Carp;
 use Socket;
 use Socket6;
