@@ -1,8 +1,8 @@
+#
+# $Id: ICMPv4.pm,v 1.2.2.28 2005/05/22 19:47:48 gomor Exp $
+#
 package Net::Packet::ICMPv4;
 
-# $Date: 2005/02/01 16:29:16 $
-# $Revision: 1.2.2.26 $
-
 use strict;
 use warnings;
 
@@ -16,9 +16,6 @@ use Net::Packet::Consts qw(:icmpv4 :layer);
 require Net::Packet::IPv4;
 require Net::Packet::Frame;
 
-require Net::Packet;
-our $VERSION = $Net::Packet::VERSION;
-
 our @AS = qw(
    type
    code
