@@ -1,8 +1,8 @@
+#
+# $Id: IPv4.pm,v 1.2.2.35 2005/05/22 19:47:48 gomor Exp $
+#
 package Net::Packet::IPv4;
 
-# $Date: 2005/02/03 22:02:01 $
-# $Revision: 1.2.2.32 $
-
 use strict;
 use warnings;
 
@@ -16,8 +16,6 @@ use Net::Packet::Utils qw(getHostIpv4Addr getRandom16bitsInt inetAton inetNtoa
    inetChecksum);
 use Net::Packet::Consts qw(:ipv4 :layer);
 
-our $VERSION = $Net::Packet::VERSION;
-
 BEGIN {
    my $osname = {
       freebsd => \&_fixLenBsd,
@@ -380,6 +378,10 @@ dst:      "127.0.0.1"
 
 options:  ""
 
+noFixLen:   0
+
+doChecksum: 0
+
 =item B<pack>
 
 Packs all attributes into a raw format, in order to inject to network. Returns 1
