@@ -1,8 +1,8 @@
+#
+# $Id: Layer.pm,v 1.2.2.21 2005/05/22 19:47:48 gomor Exp $
+#
 package Net::Packet::Layer;
 
-# $Date: 2005/02/01 16:29:16 $
-# $Revision: 1.2.2.19 $
-
 use strict;
 use warnings;
 
@@ -11,9 +11,6 @@ our @ISA = qw(Class::Gomor::Hash);
 
 use Net::Packet::Consts qw(:layer);
 
-require Net::Packet;
-our $VERSION = $Net::Packet::VERSION;
-
 our @AS = qw(
    raw
    payload
