@@ -1,8 +1,8 @@
+#
+# $Id: Layer7.pm,v 1.1.1.1.4.22 2005/05/22 19:47:48 gomor Exp $
+#
 package Net::Packet::Layer7;
 
-# $Date: 2005/02/01 16:29:16 $
-# $Revision: 1.1.1.1.4.20 $
-
 use strict;
 use warnings;
 
@@ -12,9 +12,6 @@ our @ISA = qw(Net::Packet::Layer Class::Gomor::Hash);
 
 use Net::Packet::Consts qw(:layer);
 
-require Net::Packet;
-our $VERSION = $Net::Packet::VERSION;
-
 our @AS = qw(
    data
 );
