@@ -1,8 +1,8 @@
+#
+# $Id: UDP.pm,v 1.2.2.34 2005/05/22 19:47:48 gomor Exp $
+#
 package Net::Packet::UDP;
 
-# $Date: 2005/02/01 16:29:16 $
-# $Revision: 1.2.2.32 $
-
 use strict;
 use warnings;
 
@@ -13,9 +13,6 @@ our @ISA = qw(Net::Packet::Layer4 Class::Gomor::Hash);
 use Net::Packet::Utils qw(inetChecksum getRandomHighPort inetAton inet6Aton);
 use Net::Packet::Consts qw(:udp :layer);
 
-require Net::Packet;
-our $VERSION = $Net::Packet::VERSION;
-
 our @AS = qw(
    src
    dst
